==> blocksat-cli-0.4.3.tar.gz: blocksat-cli-0.4.3/doc/frequency.md <==
---
nav_order: 10
---

# Frequency Guide

<!-- markdown-toc start - Don't edit this section. Run M-x markdown-toc-generate-toc again -->
**Table of Contents**

- [Frequency Guide](#frequency-guide)
    - [Signal Bands](#signal-bands)
    - [Signal Frequencies](#signal-frequencies)
    - [L-band Frequencies](#l-band-frequencies)

<!-- markdown-toc end -->

This page summarizes several frequencies of interest.

## Signal Bands

Blockstream Satellite operates in Ku high band, Ku low band and C band, depending on region. Ku high band is used in North America and South America. Ku low band is used in Africa, Europe, and Asia. C band is used in the Asia-Pacific region.

| Band         | Frequency Range   |
| ------------ | ----------------- |
| C band       | 3.7 GHZ - 4.2 GHz |
| Ku low band  | 10.7 to 11.7 GHz  |
| Ku high band | 11.7 to 12.75 GHz |

## Signal Frequencies

The following table summarizes the transmission bands and frequencies of the signals that we broadcast in each coverage region:

| Satellite          | Band    | Frequency    |
| ------------------ | ------- | ------------ |
| Galaxy 18          | Ku High | 12016.4 MHz  |
| Eutelsat 113       | Ku High | 12066.9 MHz  |
| Telstar 11N Africa | Ku Low  | 11480.7 MHz  |
| Telstar 11N Europe | Ku Low  | 11484.3 MHz  |
| Telstar 18V Ku     | Ku Low  | 11506.75 MHz |
| Telstar 18V C      | C       | 4053.83 MHz  |

## L-band Frequencies

Next, the following table summarizes the L-band frequencies to be used in each region based on the typical LNB local oscillator (LO) frequencies:

| LO Frequency        | 5150 MHz    | 9750 MHz    | 10600 MHz   | 10750 MHz   |
| ------------------- | ----------- | ----------- | ----------- | ----------- |
| Galaxy 18           |             |             | 1416.40 MHz | 1266.40 MHz |
| Eutelsat 113        |             |             | 1466.90 MHz | 1316.90 MHz |
| Telstar 11N Africa  |             | 1730.70 MHz |             |             |
| Telstar 11N Europe  |             | 1734.30 MHz |             |             |
| Telstar 18V Ku Band |             | 1756.75 MHz |             |             |
| Telstar 18V C Band  | 1096.17 MHz |             |             |             |

==> blocksat-cli-0.4.4.tar.gz: blocksat-cli-0.4.4/doc/frequency.md <==
---
nav_order: 10
---

# Frequency Guide

<!-- markdown-toc start - Don't edit this section. Run M-x markdown-toc-generate-toc again -->
**Table of Contents**

- [Frequency Guide](#frequency-guide)
    - [Signal Bands](#signal-bands)
    - [Signal Frequencies](#signal-frequencies)
    - [L-band Frequencies](#l-band-frequencies)

<!-- markdown-toc end -->

This page summarizes several frequencies of interest.

## Signal Bands

Blockstream Satellite operates in Ku high band, Ku low band and C band, depending on region. Ku high band is used in North America and South America. Ku low band is used in Africa, Europe, and Asia. C band is used in the Asia-Pacific region.

| Band         | Frequency Range   |
| ------------ | ----------------- |
| C band       | 3.7 GHZ - 4.2 GHz |
| Ku low band  | 10.7 to 11.7 GHz  |
| Ku high band | 11.7 to 12.75 GHz |

## Signal Frequencies

The following table summarizes the transmission bands and frequencies of the signals that we broadcast in each coverage region:

| Satellite          | Band    | Frequency    |
| ------------------ | ------- | ------------ |
| Galaxy 18          | Ku High | 12016.4 MHz  |
| Eutelsat 113       | Ku High | 12066.9 MHz  |
| Telstar 11N Africa | Ku Low  | 11452.1 MHz  |
| Telstar 11N Europe | Ku Low  | 11505.4 MHz  |
| Telstar 18V Ku     | Ku Low  | 11506.75 MHz |
| Telstar 18V C      | C       | 4053.83 MHz  |

## L-band Frequencies

Next, the following table summarizes the L-band frequencies to be used in each region based on the typical LNB local oscillator (LO) frequencies:

| LO Frequency        | 5150 MHz    | 9750 MHz    | 10600 MHz  | 10750 MHz  |
| ------------------- | ----------- | ----------- | ---------- | ---------- |
| Galaxy 18           |             |             | 1416.4 MHz | 1266.4 MHz |
| Eutelsat 113        |             |             | 1466.9 MHz | 1316.9 MHz |
| Telstar 11N Africa  |             | 1702.1 MHz  |            |            |
| Telstar 11N Europe  |             | 1755.4 MHz  |            |            |
| Telstar 18V Ku Band |             | 1756.75 MHz |            |            |
| Telstar 18V C Band  | 1096.17 MHz |             |            |            |
